/*!
 * froala_editor v2.3.0 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2016 Froala Labs
 */

/**
 * Korean
 */

$.FE.LANGUAGE['ko'] = {
  translation: {
    // Place holder
    "Type something": "\ub0b4\uc6a9\uc744 \uc785\ub825\ud558\uc138\uc694",

    // Basic formatting
    "Bold": "\uad75\uac8c",
    "Italic": "\uae30\uc6b8\uc784\uaf34",
    "Underline": "\ubc11\uc904",
    "Strikethrough": "\ucde8\uc18c\uc120",

    // Main buttons
    "Insert": "\uc0bd\uc785",
    "Delete": "\uc0ad\uc81c",
    "Cancel": "\ucde8\uc18c",
    "OK": "\uc2b9\uc778",
    "Back": "\ubc31",
    "Remove": "\uc81c\uac70",
    "More": "\ub354",
    "Update": "\uc5c5\ub370\uc774\ud2b8",
    "Style": "\uc2a4\ud0c0\uc77c",

    // Font
    "Font Family": "\uae00\uaf34",
    "Font Size": "\ud3f0\ud2b8 \ud06c\uae30",

    // Colors
    "Colors": "\uc0c9\uc0c1",
    "Background": "\ubc30\uacbd",
    "Text": "\ud14d\uc2a4\ud2b8",

    // Paragraphs
    "Paragraph Format": "\ub2e8\ub77d",
    "Normal": "\ud45c\uc900",
    "Code": "\ucf54\ub4dc",
    "Heading 1": "\uc81c\ubaa9 1",
    "Heading 2": "\uc81c\ubaa9 2",
    "Heading 3": "\uc81c\ubaa9 3",
    "Heading 4": "\uc81c\ubaa9 4",

    // Style
    "Paragraph Style": "\ub2e8\ub77d \uc2a4\ud0c0\uc77c",
    "Inline Style": "\uc778\ub77c\uc778 \uc2a4\ud0c0\uc77c",

    // Alignment
    "Align": "\uc815\ub82c",
    "Align Left": "\uc67c\ucabd\uc815\ub82c",
    "Align Center": "\uac00\uc6b4\ub370\uc815\ub82c",
    "Align Right": "\uc624\ub978\ucabd\uc815\ub82c",
    "Align Justify": "\uc591\ucabd\uc815\ub82c",
    "None": "\uc5c6\uc74c",

    // Lists
    "Ordered List": "\uc22b\uc790\ub9ac\uc2a4\ud2b8",
    "Unordered List": "\uc810 \ub9ac\uc2a4\ud2b8",

    // Indent
    "Decrease Indent": "\ub0b4\uc5b4\uc4f0\uae30",
    "Increase Indent": "\ub4e4\uc5ec\uc4f0\uae30",

    // Links
    "Insert Link": "\ub9c1\ud06c \uc0bd\uc785",
    "Open in new tab": "\uc0c8 \ud0ed\uc5d0\uc11c \uc5f4\uae30",
    "Open Link": "\ub9c1\ud06c \uc5f4\uae30",
    "Edit Link": "\ud3b8\uc9d1 \ub9c1\ud06c",
    "Unlink": "\ub9c1\ud06c\uc0ad\uc81c",
    "Choose Link": "\ub9c1\ud06c\ub97c \uc120\ud0dd",

    // Images
    "Insert Image": "\uc774\ubbf8\uc9c0 \uc0bd\uc785",
    "Upload Image": "\uc774\ubbf8\uc9c0 \uc5c5\ub85c\ub4dc",
    "By URL": "URL \ub85c",
    "Browse": "\uac80\uc0c9",
    "Drop image": "\uc774\ubbf8\uc9c0\ub97c \ub4dc\ub86d",
    "or click": "\ub610\ub294 \ud074\ub9ad",
    "Manage Images": "\uc774\ubbf8\uc9c0 \uad00\ub9ac",
    "Loading": "\ub85c\ub4dc",
    "Deleting": "\uc0ad\uc81c",
    "Tags": "\ud0dc\uadf8",
    "Are you sure? Image will be deleted.": "\ud655\uc2e4\ud55c\uac00\uc694? \uc774\ubbf8\uc9c0\uac00 \uc0ad\uc81c\ub429\ub2c8\ub2e4.",
    "Replace": "\uad50\uccb4",
    "Uploading": "\uc5c5\ub85c\ub4dc",
    "Loading image": "\ub85c\ub4dc \uc774\ubbf8\uc9c0",
    "Display": "\ub514\uc2a4\ud50c\ub808\uc774",
    "Inline": "\uc778\ub77c\uc778",
    "Break Text": "\uad6c\ubd84 \ud14d\uc2a4\ud2b8",
    "Alternate Text": "\ub300\uccb4 \ud14d\uc2a4\ud2b8",
    "Change Size": "\ud06c\uae30 \ubcc0\uacbd",
    "Width": "\ud3ed",
    "Height": "\uc2e0\uc7a5",
    "Something went wrong. Please try again.": "\ubb38\uc81c\uac00 \ubc1c\uc0dd\ud588\uc2b5\ub2c8\ub2e4. \ub2e4\uc2dc \uc2dc\ub3c4\ud558\uc2ed\uc2dc\uc624.",

    // Video
    "Insert Video": "\ube44\ub514\uc624 \uc0bd\uc785",
    "Embedded Code": "\uc784\ubca0\ub514\ub4dc \ucf54\ub4dc",

    // Tables
    "Insert Table": "\ud14c\uc774\ube14 \uc0bd\uc785",
    "Table Header": "\ud14c\uc774\ube14 \ud5e4\ub354",
    "Remove Table": "\ud14c\uc774\ube14\uc744 \uc81c\uac70",
    "Table Style": "\ud45c \uc2a4\ud0c0\uc77c",
    "Horizontal Align": "\uc218\ud3c9 \uc815\ub82c",
    "Row": "\uc5f4",
    "Insert row above": "\uc55e\uc5d0 \uc5f4\uc744 \uc0bd\uc785",
    "Insert row below": "\ub4a4\uc5d0 \uc5f4\uc744 \uc0bd\uc785",
    "Delete row": "\uc5f4 \uc0ad\uc81c",
    "Column": "\ud589",
    "Insert column before": "\uc55e\uc5d0 \ud589\uc744 \uc0bd\uc785",
    "Insert column after": "\ub4a4\uc5d0 \ud589\uc744 \uc0bd\uc785",
    "Delete column": "\ud589 \uc0ad\uc81c",
    "Cell": "\uc140",
    "Merge cells": "\uc140 \ud569\uce58\uae30",
    "Horizontal split": "\uc218\ud3c9 \ubd84\ud560",
    "Vertical split": "\uc218\uc9c1 \ubd84\ud560",
    "Cell Background": "\uc140 \ubc30\uacbd",
    "Vertical Align": "\uc218\uc9c1 \uc815\ub82c",
    "Top": "\uc0c1\ub2e8",
    "Middle": "\uc911\uac04",
    "Bottom": "\ubc14\ub2e5",
    "Align Top": "\uc0c1\ub2e8\uc744 \ub9de \ucda5\ub2c8 \ub2e4",
    "Align Middle": "\uc911\uac04 \uc815\ub82c",
    "Align Bottom": "\ubc14\ub2e5\uc744 \ub9de \ucda5\ub2c8 \ub2e4",
    "Cell Style": "\uc140 \uc2a4\ud0c0\uc77c",

    // Files
    "Upload File": "\ud30c\uc77c \ucca8\ubd80",
    "Drop file": "\ud30c\uc77c\uc744 \ub4dc\ub86d",

    // Emoticons
    "Emoticons": "\uc774\ubaa8\ud2f0\ucf58",
    "Grinning face": "\uc5bc\uad74 \uc6c3\uae30\ub9cc",
    "Grinning face with smiling eyes": "\ubbf8\uc18c\ub294 \ub208\uc744 \uac00\uc9c4 \uc5bc\uad74 \uc6c3\uae30\ub9cc",
    "Face with tears of joy": "\uae30\uc068\uc758 \ub208\ubb3c\ub85c \uc5bc\uad74",
    "Smiling face with open mouth": "\uc624\ud508 \uc785\uc73c\ub85c \uc6c3\ub294 \uc5bc\uad74",
    "Smiling face with open mouth and smiling eyes": "\uc624\ud508 \uc785\uc73c\ub85c \uc6c3\ub294 \uc5bc\uad74\uacfc \ub208\uc744 \ubbf8\uc18c",
    "Smiling face with open mouth and cold sweat": "\uc785\uc744 \uc5f4\uace0 \uc2dd\uc740 \ub540\uacfc \ud568\uaed8 \uc6c3\ub294 \uc5bc\uad74",
    "Smiling face with open mouth and tightly-closed eyes": "\uc624\ud508 \uc785\uacfc \ubc00\uc811\ud558\uac8c \ub2eb\ud78c \ub41c \ub208\uc744 \uac00\uc9c4 \uc6c3\ub294 \uc5bc\uad74",
    "Smiling face with halo": "\ud6c4\uad11 \uc6c3\ub294 \uc5bc\uad74",
    "Smiling face with horns": "\ubfd4 \uc6c3\ub294 \uc5bc\uad74",
    "Winking face": "\uc5bc\uad74 \uc719\ud06c",
    "Smiling face with smiling eyes": "\uc6c3\ub294 \ub208\uc73c\ub85c \uc6c3\ub294 \uc5bc\uad74",
    "Face savoring delicious food": "\ub9db\uc788\ub294 \uc74c\uc2dd\uc744 \uc74c\ubbf8 \uc5bc\uad74",
    "Relieved face": "\uc548\ub3c4 \uc5bc\uad74",
    "Smiling face with heart-shaped eyes": "\ud558\ud2b8 \ubaa8\uc591\uc758 \ub208\uc73c\ub85c \uc6c3\ub294 \uc5bc\uad74",
    "Smiling face with sunglasses": "\uc120\uae00\ub77c\uc2a4 \uc6c3\ub294 \uc5bc\uad74",
    "Smirking face": "\ub3c8\uc744 \uc9c0\ubd88 \uc5bc\uad74",
    "Neutral face": "\uc911\ub9bd \uc5bc\uad74",
    "Expressionless face": "\ubb34\ud45c\uc815 \uc5bc\uad74",
    "Unamused face": "\uc990\uac81\uac8c\ud558\uc9c0 \uc5bc\uad74",
    "Face with cold sweat": "\uc2dd\uc740 \ub540\uacfc \uc5bc\uad74",
    "Pensive face": "\uc7a0\uaca8\uc788\ub294 \uc5bc\uad74",
    "Confused face": "\ud63c\ub780 \uc5bc\uad74",
    "Confounded face": "\ub9dd\ud560 \uac83 \uc5bc\uad74",
    "Kissing face": "\uc5bc\uad74\uc744 \ud0a4\uc2a4",
    "Face throwing a kiss": "\ud0a4\uc2a4\ub97c \ub358\uc9c0\uace0 \uc5bc\uad74",
    "Kissing face with smiling eyes": "\ubbf8\uc18c\ub294 \ub208\uc744 \uac00\uc9c4 \uc5bc\uad74\uc744 \ud0a4\uc2a4",
    "Kissing face with closed eyes": "\ub2eb\ud78c \ub41c \ub208\uc744 \uac00\uc9c4 \uc5bc\uad74\uc744 \ud0a4\uc2a4",
    "Face with stuck out tongue": "\ub0b4\ubc00 \ud600 \uc5bc\uad74",
    "Face with stuck out tongue and winking eye": "\ub0b4\ubc00 \ud600\uc640 \uc719\ud06c \ub208\uacfc \uc5bc\uad74",
    "Face with stuck out tongue and tightly-closed eyes": "\ubc16\uc73c\ub85c \ubd99\uc5b4 \ud600\uc640 \ubc00\uc811\ud558\uac8c \ub2eb\ud78c \ub41c \ub208\uc744 \uac00\uc9c4 \uc5bc\uad74",
    "Disappointed face": "\uc2e4\ub9dd \uc5bc\uad74",
    "Worried face": "\uac71\uc815 \uc5bc\uad74",
    "Angry face": "\uc131\ub09c \uc5bc\uad74",
    "Pouting face": "\uc5bc\uad74\uc744 \uc090",
    "Crying face": "\uc5bc\uad74 \uc6b0\ub294",
    "Persevering face": "\uc5bc\uad74\uc744 \uc778\ub0b4",
    "Face with look of triumph": "\uc2b9\ub9ac\uc758 \ud45c\uc815\uc73c\ub85c \uc5bc\uad74",
    "Disappointed but relieved face": "\uc2e4\ub9dd\ud558\uc9c0\ub9cc \uc5bc\uad74\uc744 \uc548\uc2ec",
    "Frowning face with open mouth": "\uc624\ud508 \uc785\uc73c\ub85c \uc5bc\uad74\uc744 \ucc21\uadf8\ub9bc",
    "Anguished face": "\uace0\ub1cc\uc758 \uc5bc\uad74",
    "Fearful face": "\ubb34\uc11c\uc6b4 \uc5bc\uad74",
    "Weary face": "\uc9c0\uce5c \uc5bc\uad74",
    "Sleepy face": "\uc2ac\ub9ac\ud53c \uc5bc\uad74",
    "Tired face": "\ud53c\uace4 \uc5bc\uad74",
    "Grimacing face": "\uc5bc\uad74\uc744 \ucc21\uadf8\ub9b0",
    "Loudly crying face": "\ud070 \uc18c\ub9ac\ub85c \uc5bc\uad74\uc744 \uc6b8\uace0",
    "Face with open mouth": "\uc624\ud508 \uc785\uc73c\ub85c \uc5bc\uad74",
    "Hushed face": "\uc870\uc6a9\ud55c \uc5bc\uad74",
    "Face with open mouth and cold sweat": "\uc785\uc744 \uc5f4\uace0 \uc2dd\uc740 \ub540\uc73c\ub85c \uc5bc\uad74",
    "Face screaming in fear": "\uacf5\ud3ec\uc5d0 \ube44\uba85 \uc5bc\uad74",
    "Astonished face": "\ub180\ub77c \uc5bc\uad74",
    "Flushed face": "\ud50c\ub7ec\uc2dc \uc5bc\uad74",
    "Sleeping face": "\uc5bc\uad74 \uc7a0\uc790\ub294",
    "Dizzy face": "\ub514\uc9c0 \uc5bc\uad74",
    "Face without mouth": "\uc785\uc5c6\uc774 \uc5bc\uad74",
    "Face with medical mask": "\uc758\ub8cc \ub9c8\uc2a4\ud06c\ub85c \uc5bc\uad74",

    // Line breaker
    "Break": "\ub2e8\uc808",

    // Math
    "Subscript": "\uc544\ub798 \ucca8\uc790",
    "Superscript": "\uc704 \ucca8\uc790",

    // Full screen
    "Fullscreen": "\uc804\uccb4 \ud654\uba74",

    // Horizontal line
    "Insert Horizontal Line": "\uc218\ud3c9\uc120\uc744 \uc0bd\uc785",

    // Clear formatting
    "Clear Formatting": "\uc11c\uc2dd \uc81c\uac70",

    // Undo, redo
    "Undo": "\uc2e4\ud589 \ucde8\uc18c",
    "Redo": "\ub418\ub3cc\ub9ac\uae30",

    // Select all
    "Select All": "\uc804\uccb4\uc120\ud0dd",

    // Code view
    "Code View": "\ucf54\ub4dc\ubcf4\uae30",

    // Quote
    "Quote": "\uc778\uc6a9",
    "Increase": "\uc99d\uac00",
    "Decrease": "\uac10\uc18c",

    // Quick Insert
    "Quick Insert": "\ube60\ub978 \uc0bd\uc785"
  },
  direction: "ltr"
};
